..
    Copyright (C) 2020-2021 Graz University of Technology.

    invenio-theme-iform is free software; you can redistribute it and/or
    modify it under the terms of the MIT License; see LICENSE file for more
    details.

======================
 invenio-theme-iform
======================

.. image:: https://github.com/Cian-H/invenio-theme-iform/workflows/CI/badge.svg
        :target: https://github.com/Cian-H/invenio-theme-iform/actions

.. image:: https://img.shields.io/pypi/dm/invenio-theme-iform.svg
        :target: https://pypi.python.org/pypi/invenio-theme-iform

.. image:: https://img.shields.io/github/tag/tu-graz-library/invenio-theme-iform.svg
        :target: https://github.com/Cian-H/invenio-theme-iform/releases

.. image:: https://img.shields.io/github/license/tu-graz-library/invenio-theme-iform.svg
        :target: https://github.com/Cian-H/invenio-theme-iform/blob/master/LICENSE

.. image:: https://readthedocs.org/projects/invenio-theme-iform/badge/?version=latest
        :target: https://invenio-theme-iform.readthedocs.io/en/latest/?badge=latest

.. image:: https://img.shields.io/coveralls/mb-wali/invenio-theme-iform.svg
        :target: https://coveralls.io/r/mb-wali/invenio-theme-iform

.. image:: https://img.shields.io/badge/code%20style-Ruff-D7FF64.svg
    :target: https://github.com/astral-sh/ruff

I-Form standard theme.

Features:

* I-Form custom header template.
* I-Form custom footer template.
* I-Form custom login/signup templates.
* I-Form custom frontpage template.
* I-Form custom contact template.
* I-Form overriden theme.

Further documentation is available on
https://invenio-theme-iform.readthedocs.io/

Forked from https://github.com/tu-graz-library/invenio-theme-tugraz
